this function geocodes the addresses of the sinave database using Geocoding API.
geocode(infile, address)a file with extension rds.
The function use the geocode of ggmap.
The code for geocoding was taken from the personal page of Shane Lynn https://www.shanelynn.ie/massive-geocoding-with-r-and-google-maps/ and adapted to work with the sinave http://www.sinave.gob.mx/ database.
1+1
#> [1] 2